@@ -4,7 +4,7 @@ from typing import Sequence, TypeVar
 
 T = TypeVar("T")
 
-__all__ = ['first_or_default']
+__all__ = ["first_or_default"]
 
 
 def first_or_default(sequence: Sequence[T], default: T) -> T:
