@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 import sys
-from typing import Any, Optional, TextIO
+from typing import Any, Callable, Optional, TextIO
 from .actions import Action, ActionsHandler
 from .exceptions import AcceptAction, AbortAction, CustomAction, MissingHander
 from .keys import KeyEvent, KeysBinding
@@ -16,7 +16,10 @@ __all__ = [
 class Prompt(ActionsHandler):
     def __init__(
         self,
+        default: Optional[Any] = None,
         prompt_str: str = "",
+        type: Optional[Any] = None,
+        value_proc: Optional[Callable[[str], Any]] = None,
         keys_binding: Optional[KeysBinding] = None,
         output_stream: TextIO = sys.stderr,
     ):
@@ -24,13 +27,25 @@ class Prompt(ActionsHandler):
         Initializate Prompt object
 
         Args:
-            prompt_str: Input prompt
+            default: The default value to use if no input happens
+            prompt_str: The input prompt
+            type: The type to use to check the value against
+            value_proc: Type conversion function
             keys_binding: Custom keys binding
             output_stream: Output stream
         """
         super().__init__(keys_binding=keys_binding)
+        self.default = default
         self.prompt_str = prompt_str
         self.output_stream = output_stream
+        if value_proc is not None:
+            self.value_proc: Optional[Callable[[str], Any]] = value_proc
+        elif (type is not None) or (default is not None and not isinstance(default, str)):
+            from click.types import convert_type
+
+            self.value_proc = convert_type(type, default)
+        else:
+            self.value_proc = None
 
     def setup(self, input: Optional[str] = None) -> None:
         """
@@ -78,18 +93,31 @@ class Prompt(ActionsHandler):
         self.line_editor.print(self.screen)
         self.screen.flush()
 
-    def prepare_result(self) -> str:
-        return self.line_editor.line
+    def prepare_result(self) -> Any:
+        "Return the line converted to the correct type or the default value if the line is empty"
+        if not self.line_editor.line:
+            return self.default
+        elif self.value_proc is not None:
+            # value_proc raises an exception if the value is invalid
+            return self.value_proc(self.line_editor.line)
+        else:
+            return self.line_editor.line
 
     @Action("accept", keys=["enter"])
     def accept(self, key_event: KeyEvent) -> None:
         "Confirm"
-        raise AcceptAction(action="accept", ch=key_event.ch, selected_item=self.prepare_result(), line=self.line_editor.line)
+        try:
+            selected_item = self.prepare_result()
+        except Exception as ex:
+            self.screen.write(f"\nError: The value you entered was invalid: {ex}\n")
+            self.screen.flush()
+            return
+        raise AcceptAction(action="accept", ch=key_event.ch, selected_item=selected_item, line=self.line_editor.line)
 
     @Action("abort", keys=["ctrl-c", "ctrl-g", "ctrl-q", "esc"])
     def abort(self, key_event: KeyEvent) -> None:
         "Cancel"
-        raise AbortAction(action="abort", ch=key_event.ch)
+        raise AbortAction(action="abort", ch=key_event.ch, line=self.line_editor.line)
 
     @Action("ignore", keys=["null", "insert"])
     def ignore(self) -> None:
