@@ -1,37 +1,8 @@
 import pytest
-import pyte
 from pzp import pzp
-from pzp.finder import Finder
 from pzp.screen import Screen
 from pzp.exceptions import AcceptAction
-
-
-class FakeIO:
-    def __init__(self, stream):
-        self.stream = stream
-
-    def write(self, s):
-        if s:
-            return self.stream.feed(s.replace("\n", "\r\n"))
-        else:
-            return 0
-
-    def flush(self):
-        pass
-
-
-class FakeTerminal:
-    def __init__(self):
-        self.screen = pyte.Screen(80, 24)
-        self.stream = pyte.Stream(self.screen)
-        self.output_stream = FakeIO(self.stream)
-
-    @property
-    def cursor(self):
-        return self.screen.cursor
-
-    def __str__(self):
-        return "\n".join(self.screen.display)
+from .commons import FakeTerminal
 
 
 def test_screen_movements():
@@ -95,30 +66,6 @@ def test_term():
         output_stream.write(f"line{i}>\n")
     assert terminal.cursor.y == lines
 
-    candidates = [f"0x{x}" for x in range(0, 100)]
-    finder = Finder(candidates=candidates, height=10, fullscreen=True, layout="reverse-list", output_stream=output_stream)
-    finder.setup()
-    assert finder.selected == 0
-
-    finder.process_key("down")
-    finder.apply_filter()
-    finder.update_screen()
-    assert finder.selected == 1
-
-    finder.process_key("9")
-    finder.apply_filter()
-    finder.update_screen()
-    assert finder.selected == 1
-
-    finder.process_key("9")
-    finder.apply_filter()
-    finder.update_screen()
-    assert finder.selected == 0
-    assert finder.prepare_result() == "0x99"
-
-    finder.layout.screen.cleanup()
-    assert terminal.cursor.y == 0
-
 
 @pytest.mark.timeout(5)
 def test_lazy():
